@@ -1,11 +1,11 @@
 package Net::IMAP::Simple;
-# $Id: Simple.pm,v 1.10 2005/07/11 00:14:50 cfaber Exp $
+# $Id: Simple.pm,v 1.11 2005/08/06 10:38:04 cfaber Exp $
 use strict;
 use IO::File;
 use IO::Socket;
 
 use vars qw[$VERSION];
-$VERSION = '0.103';
+$VERSION = '0.104';
 
 =head1 NAME
 
@@ -404,7 +404,11 @@ sub get {
     $self->_process_cmd(
         cmd     => [FETCH => qq[$number rfc822]],
         final   => sub { pop @lines; \@lines },
-        process => sub { push @lines, $_[0] unless $_[0] =~ /^\*/ },
+        process => sub {
+		if($_[0] !~ /^\* \d+ FETCH/){
+			push @lines, join(' ', @_);
+		}
+	},
     );
 
 }
@@ -430,9 +434,11 @@ sub getfh {
         cmd     => [FETCH => qq[$number rfc822]],
         final   => sub { seek $file, 0, 0; $file },
         process => sub {
-                        defined($buffer) and print $file $buffer unless /^\*/;
+		if($_[0] !~ /^\* \d+ FETCH/){
+                        defined($buffer) and print $file $buffer;
                         $buffer = $_[0];
-                       },
+		}
+	},
     );
 }
 
